@@ -27,7 +27,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * 
- * $Id: //depot/r16.2/p4-python/P4API.cpp#1 $
+ * $Id: //depot/r17.1/p4-python/P4API.cpp#1 $
  *
  * Build instructions:
  *  Use Distutils - see accompanying setup.py
@@ -56,6 +56,7 @@
 #include "P4MapMaker.h"
 #include "PythonMessage.h"
 #include "PythonTypes.h"
+#include "debug.h"
 
 // #include <alloca.h> 
 
@@ -68,10 +69,10 @@
 using namespace std;
 
 static Ident ident = { 
-	IdentMagic "P4PYTHON" "/" ID_OS  "/"  ID_REL "/" ID_PATCH  " (" ID_API " API)",
-	ID_Y "/" ID_M "/" ID_D 
+	IdentMagic "P4PYTHON" "/" ID_OS  "/"  ID_REL "/" ID_PATCH  " (" ID_API " API)", ID_Y "/" ID_M "/" ID_D
 };
 
+
 // ===================
 // ==== P4Adapter ====
 // ===================
@@ -531,6 +532,60 @@ static PyObject * P4Adapter_disableTmpCleanup(P4Adapter * self, PyObject *args)
     return self->clientAPI->DisableTmpCleanup();
 }
 
+static PyObject * P4Adapter_setTunable(P4Adapter * self, PyObject *args)
+{
+    const char *tunable;
+    const char *value;
+
+    if( PyArg_ParseTuple(args, "ss", &tunable, &value)) {
+        // check if tunable exists
+        int index = p4tunable.GetIndex(tunable);
+        if( index >= 0) {
+            // Get the old value
+            int oldValue = p4tunable.Get(index);
+
+            // set the new tunable
+            StrBuf setter(tunable);
+            setter << "=" << value;
+
+            p4tunable.Set(setter.Text());
+
+            // return the old tunable
+
+            return PyLong_FromLong(oldValue);
+        }
+        else {
+            StrBuf errorMsg("Unknown tunable '");
+            errorMsg << tunable << "'";
+            PyErr_SetString(PyExc_TypeError, errorMsg.Text());
+            return NULL;
+        }
+    }
+    return NULL;
+}
+
+static PyObject * P4Adapter_getTunable(P4Adapter * self, PyObject *args)
+{
+    const char *tunable;
+
+    if( PyArg_ParseTuple(args, "s", &tunable)) {
+        // check if tunable exists
+        int index = p4tunable.GetIndex(tunable);
+        if( index >= 0) {
+            // Get the old value
+            int oldValue = p4tunable.Get(index);
+            return PyLong_FromLong(oldValue);
+        }
+        else {
+            StrBuf errorMsg("Unknown tunable '");
+            errorMsg << tunable << "'";
+            PyErr_SetString(PyExc_TypeError, errorMsg.Text());
+            return NULL;
+        }
+    }
+    return NULL;
+}
+
 #if PY_MAJOR_VERSION >= 3
 
 static PyObject * P4Adapter_convert(P4Adapter * self, PyObject *args)
@@ -572,6 +627,11 @@ static PyMethodDef P4Adapter_methods[] = {
       "Makes P4Python thread safe by disabling cleanup of temporary resources"},
     {"is_ignored", (PyCFunction)P4Adapter_isIgnored, METH_VARARGS,
       "Returns True if the specified file path will be ignored by the current ignore file"},
+    {"set_tunable", (PyCFunction)P4Adapter_setTunable, METH_VARARGS,
+      "Sets a tunable to the specified value"},
+    {"get_tunable", (PyCFunction)P4Adapter_getTunable, METH_VARARGS,
+      "Returns the value for this tunable or 0"},
+
 #if PY_MAJOR_VERSION >= 3
      {"__convert", (PyCFunction)P4Adapter_convert, METH_VARARGS,
      "Converts a Unicode string into a Perforce-converted String" },
