@@ -25,7 +25,7 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-$Id: //depot/r16.2/p4-python/PythonClientAPI.cpp#1 $
+$Id: //depot/r17.1/p4-python/PythonClientAPI.cpp#1 $
 *******************************************************************************/
  
 #include <Python.h>
@@ -37,6 +37,7 @@ $Id: //depot/r16.2/p4-python/PythonClientAPI.cpp#1 $
 #include <i18napi.h>
 #include <charcvt.h>
 #include <strtable.h>
+#include <strarray.h>
 #include <enviro.h>
 #include <hostenv.h>
 #include <spec.h>
@@ -145,6 +146,7 @@ PythonClientAPI::intattribute_t PythonClientAPI::intattributes[] = {
 	{ "debug",		&PythonClientAPI::SetDebug,		&PythonClientAPI::GetDebug },
 	{ "track",		&PythonClientAPI::SetTrack,		&PythonClientAPI::GetTrack },
 	{ "streams",		&PythonClientAPI::SetStreams,		&PythonClientAPI::GetStreams },
+	{ "graph",		&PythonClientAPI::SetGraph,		&PythonClientAPI::GetGraph },
 	{ "case_folding",	&PythonClientAPI::SetCaseFolding,	&PythonClientAPI::GetCaseFolding},
 	{ NULL, NULL, NULL }, // guard
 };
@@ -180,6 +182,7 @@ PythonClientAPI::objattribute_t PythonClientAPI::objattributes[] = {
         { "errors",		NULL,					&PythonClientAPI::GetErrors },
 	{ "warnings",		NULL,					&PythonClientAPI::GetWarnings },
         { "messages",		NULL,					&PythonClientAPI::GetMessages },
+	{ "p4config_files",	NULL,					&PythonClientAPI::GetConfigFiles },
 	{ "track_output",	NULL,					&PythonClientAPI::GetTrackOutput },
 	{ "__members__",	NULL,					&PythonClientAPI::GetMembers },
 	{ "server_level",	NULL,					&PythonClientAPI::GetServerLevel },
@@ -414,6 +417,21 @@ int PythonClientAPI::GetStreams()
     return IsStreamsMode() != 0;
 }
 
+int PythonClientAPI::SetGraph( int enable )
+{
+    if (enable)
+        SetGraphMode();
+    else
+        ClearGraphMode();
+
+    return 0;
+}
+
+int PythonClientAPI::GetGraph()
+{
+    return IsGraphMode() != 0;
+}
+
 int PythonClientAPI::SetCwd( const char *c )
 {
     client.SetCwd( c );
@@ -632,6 +650,22 @@ PyObject * PythonClientAPI::GetMembers() {
     return memberList;
 }
 
+PyObject * PythonClientAPI::GetConfigFiles() {
+    debug.debug( P4PYDBG_COMMANDS, "[P4] GetConfigFiles");
+
+    PyObject * configFiles = PyList_New(0); // empty list
+
+    const StrArray * configs = client.GetConfigs();
+    for (int i = 0; i < configs->Count(); i++) {
+	const StrBuf * entry = configs->Get(i);
+	PyObject * str = CreatePythonString(entry->Text());
+	PyList_Append(configFiles, str);
+	Py_DecRef( str );
+    }
+
+    return configFiles;
+}
+
 PyObject * PythonClientAPI::Connect()
 {
     debug.debug( P4PYDBG_COMMANDS, "[P4] Connecting to Perforce" );
@@ -1176,10 +1210,13 @@ void PythonClientAPI::RunCmd(const char *cmd, ClientUser *ui, int argc, char * c
 // #endif
 
     if( IsTag() )
-	client.SetVar( "tag" );
+        client.SetVar( "tag" );
 
     if( IsStreamsMode() && apiLevel >= 70 )
-	client.SetVar( "enableStreams" );
+        client.SetVar( "enableStreams" );
+
+    if ( IsGraphMode() && apiLevel > 81 )
+        client.SetVar( "enableGraph" );
 
     // If maxresults or maxscanrows is set, enforce them now
     if( maxResults  )	client.SetVar( "maxResults",  maxResults  );
