@@ -165,6 +165,6 @@ PythonSpecData::Comment( SpecElem *sd, int x, const char **wv, int nl, Error *e)
     }
     else
     {
-	cout << "*** It is not a list, I am confused" << endl;
+	// ignore these entries for now
     }
 }
