@@ -23,7 +23,7 @@
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
- $Id: //depot/r16.2/p4-python/SpecMgr.cpp#1 $
+ $Id: //depot/r17.1/p4-python/SpecMgr.cpp#1 $
  *******************************************************************************/
 
 /*******************************************************************************
@@ -55,6 +55,7 @@
 using namespace std;
 
 
+
 struct specdata {
     const char *type;
     const char *spec;
@@ -113,7 +114,6 @@ struct specdata {
 	"Backup;code:319;type:select;len:10;val:enable/disable;;"
 	"View;code:311;type:wlist;words:2;len:64;;"
 	"ChangeView;code:317;type:llist;len:64;;"
-	"RepoView;code:320;type:llist;len:64;;"
     },
     {
 	"depot",
@@ -208,6 +208,7 @@ struct specdata {
 	"Clients;code:458;len:8;;"
 	"Users;code:459;len:8;;"
 	"Files;code:460;len:8;;"
+	"Repos;code:462;len:8;;"
     },
     {
 	"protect",
@@ -217,7 +218,7 @@ struct specdata {
     },
     {
 	"remote",
-	"RemoteID;code:851;rq;ro;len:32;;"
+	"RemoteID;code:851;rq;ro;fmt:L;len:32;;"
 	"Address;code:852;rq;type:line;len:32;;"
 	"Owner;code:853;fmt:R;len:32;;"
 	"RemoteUser;code:861;fmt:R;len:32;;"
@@ -231,6 +232,17 @@ struct specdata {
 	"DepotMap;code:860;type:wlist;words:2;len:64;;"
 	"ArchiveLimits;code:862;type:wlist;words:2;len:64;;"
     },
+    {
+    "repo",
+	"Repo;code:1001;rq;ro;len:128;;"
+	"Owner;code:1002;len:32;;"
+	"Created;code:1003;type:date;ro;fmt:L;len:20;;"
+	"Pushed;code:1004;type:date;ro;fmt:L;len:20;;"
+	"ForkedFrom;code:1005;ro;len:128;;"
+	"Description;code:1006;type:text;len:128;;"
+	"DefaultBranch;code:1007;len:32;;"
+	"MirroredFrom;code:1008;len:32;;"
+	},
     {
 	"server",
 	"ServerID;code:751;rq;ro;len:32;;"
