@@ -839,6 +839,34 @@ class TestP4(TestP4Python):
         else:
             print("Test case testStreams needs a 2010.2+ Perforce Server to run")
 
+    def testGraph( self ):
+        self.p4.connect()
+        self._setClient()
+
+        if self.p4.server_level >= 43:
+            self.assertEqual( self.p4.graph, 1, "Graph is not enabled")
+
+            self.p4.graph = 0
+            self.assertEqual( self.p4.graph, 0, "Graph is not disabled")
+
+            self.p4.graph = 1
+            self.assertEqual( self.p4.graph, 1, "Graph is not re-enabled")
+
+            # create graph depot
+
+            d = self.p4.fetch_depot( "repo" )
+            d._type = 'graph'
+            self.p4.save_depot( d )
+
+            r = self.p4.fetch_repo( "//repo/repo" )
+            self.p4.save_repo( r )
+
+            # check graph depot is there
+            depots = self.p4.run_depots()
+            self.assertEqual( len(depots), 2, "Cannot see graph depot" )
+        else:
+            print("Test case testGraph needs a 2017.1 Perforce Server to run")
+
     def check_spec( self, spec_name, parameter):
         """Check a single spec.
    Takes the name and a potential parameter as an argument.
@@ -908,6 +936,7 @@ class TestP4(TestP4Python):
             'ldap'     : "test_ldap",
             'protect'  : None,
             'remote'   : "test_remote",
+            'repo'     : "//repo/repo",
             'server'   : "test_server",
             'stream'   : "//stream/main",
             'spec'     : "job", # this is the only spec I am allowed to overwrite
